@@ -86,17 +86,16 @@ def dashboardAll(db):
         cursor.execute("SELECT ROUND((Execution_Pass/Execution_Total)*100, 2) from TB_EXECUTION;")
         exe_perc_data = cursor.fetchall()
 
-        ninty_five_pass_count = get_count_by_perc(exe_perc_data,95)
-        ninty_pass_count =  get_count_by_perc(exe_perc_data,90)
-        eighty_five_pass_count = get_count_by_perc(exe_perc_data,85)
-        eighty_pass_count = get_count_by_perc(exe_perc_data,80)
+        results = []
+        results.append(get_count_by_perc(exe_perc_data, 100, 90))
+        results.append(get_count_by_perc(exe_perc_data, 89, 80))
+        results.append(get_count_by_perc(exe_perc_data, 79, 70))
+        results.append(get_count_by_perc(exe_perc_data, 69, 60))
+        results.append(get_count_by_perc(exe_perc_data, 59, 50))
+        results.append(get_count_by_perc(exe_perc_data, 49, 0))
 
         return render_template('dashboardAll.html', exe_id_avg_data=exe_id_avg_data,
-         ninty_five_pass_count=ninty_five_pass_count,
-         ninty_pass_count=ninty_pass_count,
-         eighty_five_pass_count=eighty_five_pass_count,
-         eighty_pass_count=eighty_pass_count,
-         results_data=results_data, db_name=db)
+         results=results, results_data=results_data, db_name=db)
 
     else:
         return redirect(url_for('redirect_url'))
@@ -135,6 +134,15 @@ def dashboardRecent(db):
 
         cursor.execute("SELECT Suite_Name, Suite_Fail, COUNT(Suite_Name) as F from TB_SUITE WHERE Suite_Status='FAIL' AND Execution_Id >= %s GROUP BY Suite_Name HAVING COUNT(Suite_Name) > 1 ORDER BY F DESC, Suite_Fail DESC LIMIT 5;" % exe_info[1][0])
         common_failed_suites = cursor.fetchall()
+    
+        cursor.execute("SELECT COUNT(*) From (SELECT Test_Name, Execution_Id From TB_TEST WHERE Test_Status='FAIL' AND Execution_Id >= %s GROUP BY Test_Name HAVING COUNT(Test_Name) = 1) AS T WHERE Execution_Id=%s" % (exe_info[1][0],exe_info[0][0]))
+        new_failed_tests_count = cursor.fetchall()
+
+        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Application_Issue%%';" % exe_info[0][0])
+        app_failure_anl_count = cursor.fetchall()
+
+        cursor.execute("SELECT COUNT(*) from TB_TEST WHERE Execution_Id=%s AND Test_Comment LIKE '%%Automation_Issue%%';" % exe_info[0][0])
+        auto_failure_anl_count = cursor.fetchall()
 
         # required analysis percentage
         if last_exe_data[0][1] > 0 and last_exe_data[0][1] != req_anal_data[0][0]:
@@ -147,9 +155,9 @@ def dashboardRecent(db):
         failed_test_dif = prev_exe_data[0][1] - last_exe_data[0][1]
 
         return render_template('dashboardRecent.html', last_exe_data=last_exe_data, exe_info=exe_info,
-         prev_exe_data=prev_exe_data,
-         req_anal_data=req_anal_data,
-         req_anal_perc_data=req_anal_perc_data,
+         prev_exe_data=prev_exe_data, new_failed_tests_count=new_failed_tests_count,
+         req_anal_data=req_anal_data, app_failure_anl_count=app_failure_anl_count,
+         req_anal_perc_data=req_anal_perc_data, auto_failure_anl_count=auto_failure_anl_count,
          new_tests_count=new_tests_count,
          passed_test_dif=passed_test_dif,
          failed_test_dif=failed_test_dif,
@@ -321,9 +329,18 @@ def tmetrics(db):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
+        try:
+            userField = request.form['user']
+            issueField = request.form['issue']
+        except:
+            pass
         textField = request.form['textField']
         rowField = request.form['rowField']
-        cursor.execute("Update TB_TEST SET Test_Comment='%s' WHERE Test_Id=%s;" % (str(textField), str(rowField)))
+        try:
+            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """</br><b class="text-muted">Comment: </b>""" + str(textField)
+        except:
+            comment = str(textField)
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
         mysql.connection.commit()
 
     # Get last row execution ID
@@ -357,9 +374,18 @@ def eid_tmetrics(db, eid):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
+        try:
+            userField = request.form['user']
+            issueField = request.form['issue']
+        except:
+            pass
         textField = request.form['textField']
         rowField = request.form['rowField']
-        cursor.execute("Update TB_TEST SET Test_Comment='%s' WHERE Test_Id=%s;" % (str(textField), str(rowField)))
+        try:
+            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """</br><b class="text-muted">Comment: </b>""" + str(textField)
+        except:
+            comment = str(textField)
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
         mysql.connection.commit()
 
     # Get testcase results of execution id (typically last executed)
@@ -372,9 +398,18 @@ def eid_failures(db, eid):
     cursor = mysql.connection.cursor()
     use_db(cursor, db)
     if request.method == "POST":
+        try:
+            userField = request.form['user']
+            issueField = request.form['issue']
+        except:
+            pass
         textField = request.form['textField']
         rowField = request.form['rowField']
-        cursor.execute("Update TB_TEST SET Test_Comment='%s' WHERE Test_Id=%s;" % (str(textField), str(rowField)))
+        try:
+            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """</br><b class="text-muted">Comment: </b>""" + str(textField)
+        except:
+            comment = str(textField)
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
         mysql.connection.commit()
 
     # Get testcase results of execution id (typically last executed)
@@ -382,6 +417,32 @@ def eid_failures(db, eid):
     data = cursor.fetchall()
     return render_template('failures.html', data=data, db_name=db)
 
+@app.route('/<db>/failures', methods=['GET', 'POST'])
+def recent_failures(db):
+    cursor = mysql.connection.cursor()
+    use_db(cursor, db)
+    if request.method == "POST":
+        try:
+            userField = request.form['user']
+            issueField = request.form['issue']
+        except:
+            pass
+        textField = request.form['textField']
+        rowField = request.form['rowField']
+        try:
+            comment = """<b class="text-muted">Review By: </b>""" + str(userField) + """</br><b class="text-muted">Issue Type: </b>""" + str(issueField) + """</br><b class="text-muted">Comment: </b>""" + str(textField)
+        except:
+            comment = str(textField)
+        cursor.execute('Update TB_TEST SET Test_Comment=\'%s\' WHERE Test_Id=%s;' % (str(comment), str(rowField)))
+        mysql.connection.commit()
+
+    # Get last row execution ID
+    cursor.execute("SELECT Execution_Id from TB_EXECUTION order by Execution_Id desc LIMIT 1;")
+    data = cursor.fetchone()
+    cursor.execute("SELECT * from TB_TEST WHERE Execution_Id=%s and Test_Status='FAIL';" % data)
+    data = cursor.fetchall()
+    return render_template('failures.html', data=data, db_name=db)
+
 @app.route('/<db>/search', methods=['GET', 'POST'])
 def search(db):
     if request.method == "POST":
@@ -463,10 +524,10 @@ def sort_tests(data_list):
             out[elem[1]] = list(elem)
     return [tuple(values) for values in out.values()]
 
-def get_count_by_perc(data_list, required_per):
+def get_count_by_perc(data_list, max, min):
     count = 0
     for item in data_list:
-        if item[0] > required_per:
+        if item[0] <= max and item[0] >= min:
             count += 1
     return count
 
